Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewVaultFactory ¶
func NewVaultManagerFactory ¶
func NewVaultManagerFactory() creds.ManagerFactory
Types ¶
type AuthConfig ¶
type AuthConfig struct {
ClientToken string `long:"client-token" description:"Client token for accessing secrets within the Vault server."`
Backend string `long:"auth-backend" description:"Auth backend to use for logging in to Vault."`
Params []template.VarKV `` /* 139-byte string literal not displayed */
}
type Vault ¶
type Vault struct {
VaultClient *vaultapi.Logical
PathPrefix string
TeamName string
PipelineName string
}
type VaultManager ¶
type VaultManager struct {
URL string `long:"url" description:"Vault server address used to access secrets."`
PathPrefix string `long:"path-prefix" default:"/concourse" description:"Path under which to namespace credential lookup."`
TLS struct {
CACert string `long:"ca-cert" description:"Path to a PEM-encoded CA cert file to use to verify the vault server SSL cert."`
CAPath string `` /* 127-byte string literal not displayed */
ClientCert string `long:"client-cert" description:"Path to the client certificate for Vault authorization."`
ClientKey string `long:"client-key" description:"Path to the client private key for Vault authorization."`
ServerName string `long:"server-name" description:"If set, is used to set the SNI host when connecting via TLS."`
Insecure bool `long:"insecure-skip-verify" description:"Enable insecure SSL verification."`
}
Auth AuthConfig
}
func (VaultManager) IsConfigured ¶
func (manager VaultManager) IsConfigured() bool
func (VaultManager) NewVariablesFactory ¶
func (manager VaultManager) NewVariablesFactory(logger lager.Logger) (creds.VariablesFactory, error)
func (VaultManager) Validate ¶
func (manager VaultManager) Validate() error
Click to show internal directories.
Click to hide internal directories.